/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "DPPLiveProcessCountRelay.h"
#include <boost/lexical_cast.hpp>

using namespace std;
using namespace boost;

namespace npp {

const std::string DPPLiveProcessCountRelay::TYPE = "dpp_live_process_count_relay";

DPPLiveProcessCountRelay::DPPLiveProcessCountRelay(const string& name) :
	ExperimentController(name) {

	m_count.init(this, "count");
	m_histogramController.init(this, "histogram_controller");
	m_coincidenceController.init(this, "coincidence_controller");
}

DPPLiveProcessCountRelay::~DPPLiveProcessCountRelay() {
}

void DPPLiveProcessCountRelay::postConfiguration() {
	registerUpdater(m_count->numor, &DPPLiveProcessCountRelay::updateNumor, this);
	registerProgression(m_count, &DPPLiveProcessCountRelay::updateProgression, this);

	m_histogramController->setDetectorControllers(m_count->m_DetectorControllers);
	m_coincidenceController->setDetectorControllers(m_count->m_DetectorControllers);
}

void DPPLiveProcessCountRelay::updateNumor() {
	m_histogramController->fileName = lexical_cast<string>(m_count->numor());
	m_coincidenceController->fileName = lexical_cast<string>(m_count->numor());
}

void DPPLiveProcessCountRelay::updateProgression() {
	if (m_count->commandProgression() == 100) {
		m_histogramController->stopParallel();
		m_coincidenceController->stopParallel();
	}
}

}

